==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaQtxgql.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 其它相关权利属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qtxgql"
)
public class BaQtxgql implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    @Nullable
    private Date qlqssj;

    @XmlAttribute
    @Nullable
    private Date qljssj;

    @XmlAttribute
    @Nullable
    private String qsfs;

    @XmlAttribute
    @Nullable
    private String sylx;

    @XmlAttribute
    @Nullable
    private float qsl;

    @XmlAttribute
    @Nullable
    private String qsyt;

    @XmlAttribute
    @Nullable
    private float kcmj;

    @XmlAttribute
    @Nullable
    private String kcfs;

    @XmlAttribute
    @Nullable
    private String kckz;

    @XmlAttribute
    @Nullable
    private String scgm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String ft;

    @XmlAttribute
    private String qszt;


    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String qlqx;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getQlqx() {
        return qlqx;
    }

    public void setQlqx(String qlqx) {
        this.qlqx = qlqx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public String getQsfs() {
        return qsfs;
    }

    public String getSylx() {
        return sylx;
    }

    public float getQsl() {
        return qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public float getKcmj() {
        return kcmj;
    }

    public String getKcfs() {
        return kcfs;
    }

    public String getKckz() {
        return kckz;
    }

    public String getScgm() {
        return scgm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getFt() {
        return ft;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public void setQsl(float qsl) {
        this.qsl = qsl;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public void setKcmj(float kcmj) {
        this.kcmj = kcmj;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setFt(String ft) {
        this.ft = ft;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

}

==> realestate-supervise-common-1.1.0-20251204.005843-70-sources.jar: cn/gtmap/realestate/supervise/entity/BaQtxgql.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 其它相关权利属性结构
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qtxgql"
)
public class BaQtxgql implements Serializable {

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    @Nullable
    private Date qlqssj;

    @XmlAttribute
    @Nullable
    private Date qljssj;

    @XmlAttribute
    @Nullable
    private String qsfs;

    @XmlAttribute
    @Nullable
    private String sylx;

    @XmlAttribute
    @Nullable
    private float qsl;

    @XmlAttribute
    @Nullable
    private String qsyt;

    @XmlAttribute
    @Nullable
    private float kcmj;

    @XmlAttribute
    @Nullable
    private String kcfs;

    @XmlAttribute
    @Nullable
    private String kckz;

    @XmlAttribute
    @Nullable
    private String scgm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    @Nullable
    private String ft;

    @XmlAttribute
    private String qszt;


    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String qlqx;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 原不动产单元号 */
    @XmlAttribute
    private String ybdcdyh;

    /** 用地用海分类代码 */
    @XmlAttribute
    private String ydyhfldm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getQlqx() {
        return qlqx;
    }

    public void setQlqx(String qlqx) {
        this.qlqx = qlqx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public String getQsfs() {
        return qsfs;
    }

    public String getSylx() {
        return sylx;
    }

    public float getQsl() {
        return qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public float getKcmj() {
        return kcmj;
    }

    public String getKcfs() {
        return kcfs;
    }

    public String getKckz() {
        return kckz;
    }

    public String getScgm() {
        return scgm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getFt() {
        return ft;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public void setQsl(float qsl) {
        this.qsl = qsl;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public void setKcmj(float kcmj) {
        this.kcmj = kcmj;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setFt(String ft) {
        this.ft = ft;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }
}
